@@ -180,6 +180,16 @@ Geometric <- R6Class("Geometric",
       } else {
         return(self$getParameterValue("prob") / (1 - z * self$getParameterValue("qprob")))
       }
+    },
+
+    # optional setParameterValue
+    #' @description
+    #' Sets the value(s) of the given parameter(s).
+    setParameterValue = function(..., lst = NULL, error = "warn") {
+      if (is.null(lst)) lst <- list(...)
+      if (!is.null(lst$qrob)) lst$prob <- NULL
+      super$setParameterValue(lst = lst, error = error)
+      invisible(self)
     }
   ),
 
