@@ -180,6 +180,16 @@ MultivariateNormal <- R6Class("MultivariateNormal",
       } else {
         return(super$getParameterValue(id, error))
       }
+    },
+
+    # optional setParameterValue
+    #' @description
+    #' Sets the value(s) of the given parameter(s).
+    setParameterValue = function(..., lst = NULL, error = "warn") {
+      if (is.null(lst)) lst <- list(...)
+      if (!is.null(lst$prec)) lst$cov <- NULL
+      super$setParameterValue(lst = lst, error = error)
+      invisible(self)
     }
   ),
 
