@@ -144,6 +144,21 @@ Normal <- R6Class("Normal",
     #' where X is the distribution and \eqn{E_X} is the expectation of the distribution X.
     pgf = function(z) {
       return(NaN)
+    },
+
+    # optional setParameterValue
+    #' @description
+    #' Sets the value(s) of the given parameter(s).
+    setParameterValue = function(..., lst = NULL, error = "warn") {
+      if (is.null(lst)) lst <- list(...)
+      if (!is.null(lst$prec)) {
+        lst$sd <- NULL
+        lst$var <- NULL
+      } else if (!is.null(lst$sd)) {
+        lst$var <- NULL
+      }
+      super$setParameterValue(lst = lst, error = error)
+      invisible(self)
     }
   ),
 
