@@ -150,7 +150,7 @@ Uniform <- R6Class("Uniform",
     #' @description
     #' Sets the value(s) of the given parameter(s).
     setParameterValue = function(..., lst = NULL, error = "warn") {
-      super$setParameterValue(lst = lst, error = error)
+      super$setParameterValue(..., lst = lst, error = error)
       private$.properties$support <- Interval$new(
         self$getParameterValue("lower"),
         self$getParameterValue("upper")
